---
meta:
    title: Data Subsetter
    description:
layout: component
---

```html:preview
<terra-data-subsetter collection-entry-id="OMAERO_003"></terra-data-subsetter>
```

## Examples

### First Example

TODO

### Second Example

TODO

[component-metadata:terra-data-subsetter]
